@@ -1,8 +1,6 @@
 from ..node import Node
 from .program_module import ProgramModule
 from gql import gql
-import datetime
-import polling
 
 programTrackActionFragment = """
 fragment ProgramTrackAction on ProgramTrackAction {
@@ -10,6 +8,7 @@ fragment ProgramTrackAction on ProgramTrackAction {
     sourceProgramModule {
         id
     }
+    waitsForFeedback
 }
 """
 
@@ -18,6 +17,10 @@ class ProgramTrackAction(Node):
     def __init__(self, data, context=None):
         super().__init__(data, context=context)
 
+    @property
+    def waits_for_feedback(self) -> bool:
+        return self._data["waitsForFeedback"]
+
     @property
     def module(self):
         if not self._data["sourceProgramModule"]:
@@ -59,13 +62,13 @@ class ProgramTrackAction(Node):
 
         return responses
 
-    def poll_responses(self):
-        return self._context.client.poll_program_track_action_responses(
-            {"programTrackActionId": self.id}
+    async def poll_responses(self):
+        return await self._context.client.poll_program_track_action_responses(
+            {"programTrackActionId": {"eq": self.id}}
         )
 
-    def wait_for_response(self):
-        responses = self.poll_responses()
+    async def wait_for_response(self):
+        responses = await self.poll_responses()
         return responses[0]
 
     # def add_step(self, step_name: str, text_block_content: str):
